@@ -14,7 +14,7 @@ use Config::OpenSSH::Authkey::Entry ();
 
 use IO::Handle qw(getline);
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 ######################################################################
 #
@@ -193,7 +193,10 @@ Config::OpenSSH::Authkey - interface to OpenSSH authorized_keys data
   use Config::OpenSSH::Authkey ();
   my $ak = Config::OpenSSH::Authkey->new;
   
-  TODO
+  $ak->file( 'authorized_keys' );
+  
+  while (my $entry = $ak->iterate) {
+    ...
 
 =head1 DESCRIPTION
 
@@ -211,7 +214,7 @@ were consulted in the creation of this module.
 Consult the L<"OPTIONS"> section for means to customize how
 C<authorized_keys> data is handled.
 
-=head1 METHODS
+=head1 CLASS METHODS
 
 =over 4
 
@@ -225,6 +228,12 @@ alter how the instance behaves.
     nostore_nonkey_data => 1,
   });
 
+=back
+
+=head1 INSTANCE METHODS
+
+=over 4
+
 =item B<fh>
 
 Accepts a filehandle, stores this handle in the instance, for future use
@@ -274,9 +283,8 @@ L<Config::OpenSSH::Authkey::Entry> object.
 
 =item B<get_stored_keys>
 
-Instance method. Returns an array reference of any public keys stored in
-the instance. B<keys> will only be populated if the B<auto_store> option
-is enabled.
+Returns an array reference of any public keys stored in the instance.
+B<keys> will only be populated if the B<auto_store> option is enabled.
 
 Keys will be either C<Config::OpenSSH::Authkey::MetaEntry> (comments,
 blank lines) or L<Config::OpenSSH::Authkey::Entry> (public key) objects.
@@ -326,11 +334,13 @@ method always returns these lines, regardless of this setting.
 
 =head1 Config::OpenSSH::Authkey::MetaEntry
 
-Utility class that stores blank lines or comments. Objects of this type
-should only be created by the B<parse_fh> or B<parse_file> methods. The
-object supports an B<as_string> method that will return the line.
-Disable the parsing of this data by enabling the B<nostore_nonkey_data>
-option prior to calling a B<parse_f*> method.
+Utility class that stores blank lines or comments. The object
+supports an B<as_string> method that will return the line. Disable
+the storage of this data in the key store by enabling the
+B<nostore_nonkey_data> option.
+
+Use the C<ref> function or the C<can> method to distinguish these
+entries from L<Config::OpenSSH::Authkey::Entry> objects.
 
 =head1 BUGS
 
